import java.io
import java.lang
import java.rmi.activation
import java.rmi.dgc
import java.rmi.registry
import java.rmi.server
import typing



class AlreadyBoundException(java.lang.Exception):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

_MarshalledObject__T = typing.TypeVar('_MarshalledObject__T')  # <T>
class MarshalledObject(java.io.Serializable, typing.Generic[_MarshalledObject__T]):
    def __init__(self, t: _MarshalledObject__T): ...
    def equals(self, object: typing.Any) -> bool: ...
    def get(self) -> _MarshalledObject__T: ...
    def hashCode(self) -> int: ...

class Naming:
    @staticmethod
    def bind(string: str, remote: 'Remote') -> None: ...
    @staticmethod
    def list(string: str) -> typing.List[str]: ...
    @staticmethod
    def lookup(string: str) -> 'Remote': ...
    @staticmethod
    def rebind(string: str, remote: 'Remote') -> None: ...
    @staticmethod
    def unbind(string: str) -> None: ...

class NotBoundException(java.lang.Exception):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class RMISecurityException(java.lang.SecurityException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str): ...

class RMISecurityManager(java.lang.SecurityManager):
    def __init__(self): ...

class Remote: ...

class RemoteException(java.io.IOException):
    detail: java.lang.Throwable = ...
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    def getCause(self) -> java.lang.Throwable: ...
    def getMessage(self) -> str: ...

class AccessException(RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class ConnectException(RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class ConnectIOException(RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class MarshalException(RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class NoSuchObjectException(RemoteException):
    def __init__(self, string: str): ...

class ServerError(RemoteException):
    def __init__(self, string: str, error: java.lang.Error): ...

class ServerException(RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class ServerRuntimeException(RemoteException):
    def __init__(self, string: str, exception: java.lang.Exception): ...

class StubNotFoundException(RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class UnexpectedException(RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class UnknownHostException(RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class UnmarshalException(RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.rmi")``.

    AccessException: typing.Type[AccessException]
    AlreadyBoundException: typing.Type[AlreadyBoundException]
    ConnectException: typing.Type[ConnectException]
    ConnectIOException: typing.Type[ConnectIOException]
    MarshalException: typing.Type[MarshalException]
    MarshalledObject: typing.Type[MarshalledObject]
    Naming: typing.Type[Naming]
    NoSuchObjectException: typing.Type[NoSuchObjectException]
    NotBoundException: typing.Type[NotBoundException]
    RMISecurityException: typing.Type[RMISecurityException]
    RMISecurityManager: typing.Type[RMISecurityManager]
    Remote: typing.Type[Remote]
    RemoteException: typing.Type[RemoteException]
    ServerError: typing.Type[ServerError]
    ServerException: typing.Type[ServerException]
    ServerRuntimeException: typing.Type[ServerRuntimeException]
    StubNotFoundException: typing.Type[StubNotFoundException]
    UnexpectedException: typing.Type[UnexpectedException]
    UnknownHostException: typing.Type[UnknownHostException]
    UnmarshalException: typing.Type[UnmarshalException]
    activation: java.rmi.activation.__module_protocol__
    dgc: java.rmi.dgc.__module_protocol__
    registry: java.rmi.registry.__module_protocol__
    server: java.rmi.server.__module_protocol__



import java.applet
import java.awt
import java.beans.beancontext
import java.io
import java.lang
import java.lang.annotation
import java.lang.reflect
import java.util
import org.xml.sax
import org.xml.sax.helpers
import typing



class AppletInitializer:
    def activate(self, applet: java.applet.Applet) -> None: ...
    def initialize(self, applet: java.applet.Applet, beanContext: java.beans.beancontext.BeanContext) -> None: ...

class BeanInfo:
    ICON_COLOR_16x16: typing.ClassVar[int] = ...
    ICON_COLOR_32x32: typing.ClassVar[int] = ...
    ICON_MONO_16x16: typing.ClassVar[int] = ...
    ICON_MONO_32x32: typing.ClassVar[int] = ...
    def getAdditionalBeanInfo(self) -> typing.List['BeanInfo']: ...
    def getBeanDescriptor(self) -> 'BeanDescriptor': ...
    def getDefaultEventIndex(self) -> int: ...
    def getDefaultPropertyIndex(self) -> int: ...
    def getEventSetDescriptors(self) -> typing.List['EventSetDescriptor']: ...
    def getIcon(self, int: int) -> java.awt.Image: ...
    def getMethodDescriptors(self) -> typing.List['MethodDescriptor']: ...
    def getPropertyDescriptors(self) -> typing.List['PropertyDescriptor']: ...

class BeanProperty(java.lang.annotation.Annotation):
    def bound(self) -> bool: ...
    def description(self) -> str: ...
    def enumerationValues(self) -> typing.List[str]: ...
    def equals(self, object: typing.Any) -> bool: ...
    def expert(self) -> bool: ...
    def hashCode(self) -> int: ...
    def hidden(self) -> bool: ...
    def preferred(self) -> bool: ...
    def required(self) -> bool: ...
    def toString(self) -> str: ...
    def visualUpdate(self) -> bool: ...

class Beans:
    def __init__(self): ...
    @staticmethod
    def getInstanceOf(object: typing.Any, class_: typing.Type[typing.Any]) -> typing.Any: ...
    @typing.overload
    @staticmethod
    def instantiate(classLoader: java.lang.ClassLoader, string: str) -> typing.Any: ...
    @typing.overload
    @staticmethod
    def instantiate(classLoader: java.lang.ClassLoader, string: str, beanContext: java.beans.beancontext.BeanContext) -> typing.Any: ...
    @typing.overload
    @staticmethod
    def instantiate(classLoader: java.lang.ClassLoader, string: str, beanContext: java.beans.beancontext.BeanContext, appletInitializer: AppletInitializer) -> typing.Any: ...
    @staticmethod
    def isDesignTime() -> bool: ...
    @staticmethod
    def isGuiAvailable() -> bool: ...
    @staticmethod
    def isInstanceOf(object: typing.Any, class_: typing.Type[typing.Any]) -> bool: ...
    @staticmethod
    def setDesignTime(boolean: bool) -> None: ...
    @staticmethod
    def setGuiAvailable(boolean: bool) -> None: ...

class ConstructorProperties(java.lang.annotation.Annotation):
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def value(self) -> typing.List[str]: ...

class Customizer:
    def addPropertyChangeListener(self, propertyChangeListener: 'PropertyChangeListener') -> None: ...
    def removePropertyChangeListener(self, propertyChangeListener: 'PropertyChangeListener') -> None: ...
    def setObject(self, object: typing.Any) -> None: ...

class DesignMode:
    PROPERTYNAME: typing.ClassVar[str] = ...
    def isDesignTime(self) -> bool: ...
    def setDesignTime(self, boolean: bool) -> None: ...

class Encoder:
    def __init__(self): ...
    def get(self, object: typing.Any) -> typing.Any: ...
    def getExceptionListener(self) -> 'ExceptionListener': ...
    def getPersistenceDelegate(self, class_: typing.Type[typing.Any]) -> 'PersistenceDelegate': ...
    def remove(self, object: typing.Any) -> typing.Any: ...
    def setExceptionListener(self, exceptionListener: 'ExceptionListener') -> None: ...
    def setPersistenceDelegate(self, class_: typing.Type[typing.Any], persistenceDelegate: 'PersistenceDelegate') -> None: ...
    def writeExpression(self, expression: 'Expression') -> None: ...
    def writeStatement(self, statement: 'Statement') -> None: ...

class EventHandler(java.lang.reflect.InvocationHandler):
    def __init__(self, object: typing.Any, string: str, string2: str, string3: str): ...
    _create_0__T = typing.TypeVar('_create_0__T')  # <T>
    _create_1__T = typing.TypeVar('_create_1__T')  # <T>
    _create_2__T = typing.TypeVar('_create_2__T')  # <T>
    @typing.overload
    @staticmethod
    def create(class_: typing.Type[_create_0__T], object: typing.Any, string: str) -> _create_0__T: ...
    @typing.overload
    @staticmethod
    def create(class_: typing.Type[_create_1__T], object: typing.Any, string: str, string2: str) -> _create_1__T: ...
    @typing.overload
    @staticmethod
    def create(class_: typing.Type[_create_2__T], object: typing.Any, string: str, string2: str, string3: str) -> _create_2__T: ...
    def getAction(self) -> str: ...
    def getEventPropertyName(self) -> str: ...
    def getListenerMethodName(self) -> str: ...
    def getTarget(self) -> typing.Any: ...
    def invoke(self, object: typing.Any, method: java.lang.reflect.Method, objectArray: typing.List[typing.Any]) -> typing.Any: ...

class ExceptionListener:
    def exceptionThrown(self, exception: java.lang.Exception) -> None: ...

class FeatureDescriptor:
    def __init__(self): ...
    def attributeNames(self) -> java.util.Enumeration[str]: ...
    def getDisplayName(self) -> str: ...
    def getName(self) -> str: ...
    def getShortDescription(self) -> str: ...
    def getValue(self, string: str) -> typing.Any: ...
    def isExpert(self) -> bool: ...
    def isHidden(self) -> bool: ...
    def isPreferred(self) -> bool: ...
    def setDisplayName(self, string: str) -> None: ...
    def setExpert(self, boolean: bool) -> None: ...
    def setHidden(self, boolean: bool) -> None: ...
    def setName(self, string: str) -> None: ...
    def setPreferred(self, boolean: bool) -> None: ...
    def setShortDescription(self, string: str) -> None: ...
    def setValue(self, string: str, object: typing.Any) -> None: ...
    def toString(self) -> str: ...

class IntrospectionException(java.lang.Exception):
    def __init__(self, string: str): ...

class Introspector:
    USE_ALL_BEANINFO: typing.ClassVar[int] = ...
    IGNORE_IMMEDIATE_BEANINFO: typing.ClassVar[int] = ...
    IGNORE_ALL_BEANINFO: typing.ClassVar[int] = ...
    @staticmethod
    def decapitalize(string: str) -> str: ...
    @staticmethod
    def flushCaches() -> None: ...
    @staticmethod
    def flushFromCaches(class_: typing.Type[typing.Any]) -> None: ...
    @typing.overload
    @staticmethod
    def getBeanInfo(class_: typing.Type[typing.Any]) -> BeanInfo: ...
    @typing.overload
    @staticmethod
    def getBeanInfo(class_: typing.Type[typing.Any], int: int) -> BeanInfo: ...
    @typing.overload
    @staticmethod
    def getBeanInfo(class_: typing.Type[typing.Any], class2: typing.Type[typing.Any]) -> BeanInfo: ...
    @typing.overload
    @staticmethod
    def getBeanInfo(class_: typing.Type[typing.Any], class2: typing.Type[typing.Any], int: int) -> BeanInfo: ...
    @staticmethod
    def getBeanInfoSearchPath() -> typing.List[str]: ...
    @staticmethod
    def setBeanInfoSearchPath(stringArray: typing.List[str]) -> None: ...

class JavaBean(java.lang.annotation.Annotation):
    def defaultEventSet(self) -> str: ...
    def defaultProperty(self) -> str: ...
    def description(self) -> str: ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class PersistenceDelegate:
    def __init__(self): ...
    def writeObject(self, object: typing.Any, encoder: Encoder) -> None: ...

class PropertyChangeEvent(java.util.EventObject):
    def __init__(self, object: typing.Any, string: str, object2: typing.Any, object3: typing.Any): ...
    def getNewValue(self) -> typing.Any: ...
    def getOldValue(self) -> typing.Any: ...
    def getPropagationId(self) -> typing.Any: ...
    def getPropertyName(self) -> str: ...
    def setPropagationId(self, object: typing.Any) -> None: ...
    def toString(self) -> str: ...

class PropertyChangeListener(java.util.EventListener):
    def propertyChange(self, propertyChangeEvent: PropertyChangeEvent) -> None: ...

class PropertyChangeSupport(java.io.Serializable):
    def __init__(self, object: typing.Any): ...
    @typing.overload
    def addPropertyChangeListener(self, propertyChangeListener: PropertyChangeListener) -> None: ...
    @typing.overload
    def addPropertyChangeListener(self, string: str, propertyChangeListener: PropertyChangeListener) -> None: ...
    @typing.overload
    def fireIndexedPropertyChange(self, string: str, int: int, boolean: bool, boolean2: bool) -> None: ...
    @typing.overload
    def fireIndexedPropertyChange(self, string: str, int: int, int2: int, int3: int) -> None: ...
    @typing.overload
    def fireIndexedPropertyChange(self, string: str, int: int, object: typing.Any, object2: typing.Any) -> None: ...
    @typing.overload
    def firePropertyChange(self, propertyChangeEvent: PropertyChangeEvent) -> None: ...
    @typing.overload
    def firePropertyChange(self, string: str, boolean: bool, boolean2: bool) -> None: ...
    @typing.overload
    def firePropertyChange(self, string: str, int: int, int2: int) -> None: ...
    @typing.overload
    def firePropertyChange(self, string: str, object: typing.Any, object2: typing.Any) -> None: ...
    @typing.overload
    def getPropertyChangeListeners(self) -> typing.List[PropertyChangeListener]: ...
    @typing.overload
    def getPropertyChangeListeners(self, string: str) -> typing.List[PropertyChangeListener]: ...
    def hasListeners(self, string: str) -> bool: ...
    @typing.overload
    def removePropertyChangeListener(self, propertyChangeListener: PropertyChangeListener) -> None: ...
    @typing.overload
    def removePropertyChangeListener(self, string: str, propertyChangeListener: PropertyChangeListener) -> None: ...

class PropertyEditor:
    def addPropertyChangeListener(self, propertyChangeListener: PropertyChangeListener) -> None: ...
    def getAsText(self) -> str: ...
    def getCustomEditor(self) -> java.awt.Component: ...
    def getJavaInitializationString(self) -> str: ...
    def getTags(self) -> typing.List[str]: ...
    def getValue(self) -> typing.Any: ...
    def isPaintable(self) -> bool: ...
    def paintValue(self, graphics: java.awt.Graphics, rectangle: java.awt.Rectangle) -> None: ...
    def removePropertyChangeListener(self, propertyChangeListener: PropertyChangeListener) -> None: ...
    def setAsText(self, string: str) -> None: ...
    def setValue(self, object: typing.Any) -> None: ...
    def supportsCustomEditor(self) -> bool: ...

class PropertyEditorManager:
    def __init__(self): ...
    @staticmethod
    def findEditor(class_: typing.Type[typing.Any]) -> PropertyEditor: ...
    @staticmethod
    def getEditorSearchPath() -> typing.List[str]: ...
    @staticmethod
    def registerEditor(class_: typing.Type[typing.Any], class2: typing.Type[typing.Any]) -> None: ...
    @staticmethod
    def setEditorSearchPath(stringArray: typing.List[str]) -> None: ...

class PropertyVetoException(java.lang.Exception):
    def __init__(self, string: str, propertyChangeEvent: PropertyChangeEvent): ...
    def getPropertyChangeEvent(self) -> PropertyChangeEvent: ...

class Statement:
    def __init__(self, object: typing.Any, string: str, objectArray: typing.List[typing.Any]): ...
    def execute(self) -> None: ...
    def getArguments(self) -> typing.List[typing.Any]: ...
    def getMethodName(self) -> str: ...
    def getTarget(self) -> typing.Any: ...
    def toString(self) -> str: ...

class Transient(java.lang.annotation.Annotation):
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def value(self) -> bool: ...

class VetoableChangeListener(java.util.EventListener):
    def vetoableChange(self, propertyChangeEvent: PropertyChangeEvent) -> None: ...

class VetoableChangeSupport(java.io.Serializable):
    def __init__(self, object: typing.Any): ...
    @typing.overload
    def addVetoableChangeListener(self, vetoableChangeListener: VetoableChangeListener) -> None: ...
    @typing.overload
    def addVetoableChangeListener(self, string: str, vetoableChangeListener: VetoableChangeListener) -> None: ...
    @typing.overload
    def fireVetoableChange(self, propertyChangeEvent: PropertyChangeEvent) -> None: ...
    @typing.overload
    def fireVetoableChange(self, string: str, boolean: bool, boolean2: bool) -> None: ...
    @typing.overload
    def fireVetoableChange(self, string: str, int: int, int2: int) -> None: ...
    @typing.overload
    def fireVetoableChange(self, string: str, object: typing.Any, object2: typing.Any) -> None: ...
    @typing.overload
    def getVetoableChangeListeners(self) -> typing.List[VetoableChangeListener]: ...
    @typing.overload
    def getVetoableChangeListeners(self, string: str) -> typing.List[VetoableChangeListener]: ...
    def hasListeners(self, string: str) -> bool: ...
    @typing.overload
    def removeVetoableChangeListener(self, vetoableChangeListener: VetoableChangeListener) -> None: ...
    @typing.overload
    def removeVetoableChangeListener(self, string: str, vetoableChangeListener: VetoableChangeListener) -> None: ...

class Visibility:
    def avoidingGui(self) -> bool: ...
    def dontUseGui(self) -> None: ...
    def needsGui(self) -> bool: ...
    def okToUseGui(self) -> None: ...

class XMLDecoder(java.lang.AutoCloseable):
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, object: typing.Any): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, object: typing.Any, exceptionListener: ExceptionListener): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, object: typing.Any, exceptionListener: ExceptionListener, classLoader: java.lang.ClassLoader): ...
    @typing.overload
    def __init__(self, inputSource: org.xml.sax.InputSource): ...
    def close(self) -> None: ...
    @staticmethod
    def createHandler(object: typing.Any, exceptionListener: ExceptionListener, classLoader: java.lang.ClassLoader) -> org.xml.sax.helpers.DefaultHandler: ...
    def getExceptionListener(self) -> ExceptionListener: ...
    def getOwner(self) -> typing.Any: ...
    def readObject(self) -> typing.Any: ...
    def setExceptionListener(self, exceptionListener: ExceptionListener) -> None: ...
    def setOwner(self, object: typing.Any) -> None: ...

class BeanDescriptor(FeatureDescriptor):
    @typing.overload
    def __init__(self, class_: typing.Type[typing.Any]): ...
    @typing.overload
    def __init__(self, class_: typing.Type[typing.Any], class2: typing.Type[typing.Any]): ...
    def getBeanClass(self) -> typing.Type[typing.Any]: ...
    def getCustomizerClass(self) -> typing.Type[typing.Any]: ...

class DefaultPersistenceDelegate(PersistenceDelegate):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, stringArray: typing.List[str]): ...

class EventSetDescriptor(FeatureDescriptor):
    @typing.overload
    def __init__(self, class_: typing.Type[typing.Any], string: str, class2: typing.Type[typing.Any], string2: str): ...
    @typing.overload
    def __init__(self, class_: typing.Type[typing.Any], string: str, class2: typing.Type[typing.Any], stringArray: typing.List[str], string3: str, string4: str): ...
    @typing.overload
    def __init__(self, class_: typing.Type[typing.Any], string: str, class2: typing.Type[typing.Any], stringArray: typing.List[str], string3: str, string4: str, string5: str): ...
    @typing.overload
    def __init__(self, string: str, class_: typing.Type[typing.Any], methodDescriptorArray: typing.List['MethodDescriptor'], method2: java.lang.reflect.Method, method3: java.lang.reflect.Method): ...
    @typing.overload
    def __init__(self, string: str, class_: typing.Type[typing.Any], methodArray: typing.List[java.lang.reflect.Method], method2: java.lang.reflect.Method, method3: java.lang.reflect.Method): ...
    @typing.overload
    def __init__(self, string: str, class_: typing.Type[typing.Any], methodArray: typing.List[java.lang.reflect.Method], method2: java.lang.reflect.Method, method3: java.lang.reflect.Method, method4: java.lang.reflect.Method): ...
    def getAddListenerMethod(self) -> java.lang.reflect.Method: ...
    def getGetListenerMethod(self) -> java.lang.reflect.Method: ...
    def getListenerMethodDescriptors(self) -> typing.List['MethodDescriptor']: ...
    def getListenerMethods(self) -> typing.List[java.lang.reflect.Method]: ...
    def getListenerType(self) -> typing.Type[typing.Any]: ...
    def getRemoveListenerMethod(self) -> java.lang.reflect.Method: ...
    def isInDefaultEventSet(self) -> bool: ...
    def isUnicast(self) -> bool: ...
    def setInDefaultEventSet(self, boolean: bool) -> None: ...
    def setUnicast(self, boolean: bool) -> None: ...

class Expression(Statement):
    @typing.overload
    def __init__(self, object: typing.Any, object2: typing.Any, string: str, objectArray: typing.List[typing.Any]): ...
    @typing.overload
    def __init__(self, object: typing.Any, string: str, objectArray: typing.List[typing.Any]): ...
    def execute(self) -> None: ...
    def getValue(self) -> typing.Any: ...
    def setValue(self, object: typing.Any) -> None: ...
    def toString(self) -> str: ...

class IndexedPropertyChangeEvent(PropertyChangeEvent):
    def __init__(self, object: typing.Any, string: str, object2: typing.Any, object3: typing.Any, int: int): ...
    def getIndex(self) -> int: ...

class MethodDescriptor(FeatureDescriptor):
    @typing.overload
    def __init__(self, method: java.lang.reflect.Method): ...
    @typing.overload
    def __init__(self, method: java.lang.reflect.Method, parameterDescriptorArray: typing.List['ParameterDescriptor']): ...
    def getMethod(self) -> java.lang.reflect.Method: ...
    def getParameterDescriptors(self) -> typing.List['ParameterDescriptor']: ...

class ParameterDescriptor(FeatureDescriptor):
    def __init__(self): ...

class PropertyChangeListenerProxy(java.util.EventListenerProxy[PropertyChangeListener], PropertyChangeListener):
    def __init__(self, string: str, propertyChangeListener: PropertyChangeListener): ...
    def getPropertyName(self) -> str: ...
    def propertyChange(self, propertyChangeEvent: PropertyChangeEvent) -> None: ...

class PropertyDescriptor(FeatureDescriptor):
    @typing.overload
    def __init__(self, string: str, class_: typing.Type[typing.Any]): ...
    @typing.overload
    def __init__(self, string: str, class_: typing.Type[typing.Any], string2: str, string3: str): ...
    @typing.overload
    def __init__(self, string: str, method: java.lang.reflect.Method, method2: java.lang.reflect.Method): ...
    def createPropertyEditor(self, object: typing.Any) -> PropertyEditor: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getPropertyEditorClass(self) -> typing.Type[typing.Any]: ...
    def getPropertyType(self) -> typing.Type[typing.Any]: ...
    def getReadMethod(self) -> java.lang.reflect.Method: ...
    def getWriteMethod(self) -> java.lang.reflect.Method: ...
    def hashCode(self) -> int: ...
    def isBound(self) -> bool: ...
    def isConstrained(self) -> bool: ...
    def setBound(self, boolean: bool) -> None: ...
    def setConstrained(self, boolean: bool) -> None: ...
    def setPropertyEditorClass(self, class_: typing.Type[typing.Any]) -> None: ...
    def setReadMethod(self, method: java.lang.reflect.Method) -> None: ...
    def setWriteMethod(self, method: java.lang.reflect.Method) -> None: ...

class PropertyEditorSupport(PropertyEditor):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, object: typing.Any): ...
    def addPropertyChangeListener(self, propertyChangeListener: PropertyChangeListener) -> None: ...
    def firePropertyChange(self) -> None: ...
    def getAsText(self) -> str: ...
    def getCustomEditor(self) -> java.awt.Component: ...
    def getJavaInitializationString(self) -> str: ...
    def getSource(self) -> typing.Any: ...
    def getTags(self) -> typing.List[str]: ...
    def getValue(self) -> typing.Any: ...
    def isPaintable(self) -> bool: ...
    def paintValue(self, graphics: java.awt.Graphics, rectangle: java.awt.Rectangle) -> None: ...
    def removePropertyChangeListener(self, propertyChangeListener: PropertyChangeListener) -> None: ...
    def setAsText(self, string: str) -> None: ...
    def setSource(self, object: typing.Any) -> None: ...
    def setValue(self, object: typing.Any) -> None: ...
    def supportsCustomEditor(self) -> bool: ...

class SimpleBeanInfo(BeanInfo):
    def __init__(self): ...
    def getAdditionalBeanInfo(self) -> typing.List[BeanInfo]: ...
    def getBeanDescriptor(self) -> BeanDescriptor: ...
    def getDefaultEventIndex(self) -> int: ...
    def getDefaultPropertyIndex(self) -> int: ...
    def getEventSetDescriptors(self) -> typing.List[EventSetDescriptor]: ...
    def getIcon(self, int: int) -> java.awt.Image: ...
    def getMethodDescriptors(self) -> typing.List[MethodDescriptor]: ...
    def getPropertyDescriptors(self) -> typing.List[PropertyDescriptor]: ...
    def loadImage(self, string: str) -> java.awt.Image: ...

class VetoableChangeListenerProxy(java.util.EventListenerProxy[VetoableChangeListener], VetoableChangeListener):
    def __init__(self, string: str, vetoableChangeListener: VetoableChangeListener): ...
    def getPropertyName(self) -> str: ...
    def vetoableChange(self, propertyChangeEvent: PropertyChangeEvent) -> None: ...

class XMLEncoder(Encoder, java.lang.AutoCloseable):
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, string: str, boolean: bool, int: int): ...
    def close(self) -> None: ...
    def flush(self) -> None: ...
    def getOwner(self) -> typing.Any: ...
    def setOwner(self, object: typing.Any) -> None: ...
    def writeExpression(self, expression: Expression) -> None: ...
    def writeObject(self, object: typing.Any) -> None: ...
    def writeStatement(self, statement: Statement) -> None: ...

class IndexedPropertyDescriptor(PropertyDescriptor):
    @typing.overload
    def __init__(self, string: str, class_: typing.Type[typing.Any]): ...
    @typing.overload
    def __init__(self, string: str, class_: typing.Type[typing.Any], string2: str, string3: str, string4: str, string5: str): ...
    @typing.overload
    def __init__(self, string: str, method: java.lang.reflect.Method, method2: java.lang.reflect.Method, method3: java.lang.reflect.Method, method4: java.lang.reflect.Method): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getIndexedPropertyType(self) -> typing.Type[typing.Any]: ...
    def getIndexedReadMethod(self) -> java.lang.reflect.Method: ...
    def getIndexedWriteMethod(self) -> java.lang.reflect.Method: ...
    def hashCode(self) -> int: ...
    def setIndexedReadMethod(self, method: java.lang.reflect.Method) -> None: ...
    def setIndexedWriteMethod(self, method: java.lang.reflect.Method) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.beans")``.

    AppletInitializer: typing.Type[AppletInitializer]
    BeanDescriptor: typing.Type[BeanDescriptor]
    BeanInfo: typing.Type[BeanInfo]
    BeanProperty: typing.Type[BeanProperty]
    Beans: typing.Type[Beans]
    ConstructorProperties: typing.Type[ConstructorProperties]
    Customizer: typing.Type[Customizer]
    DefaultPersistenceDelegate: typing.Type[DefaultPersistenceDelegate]
    DesignMode: typing.Type[DesignMode]
    Encoder: typing.Type[Encoder]
    EventHandler: typing.Type[EventHandler]
    EventSetDescriptor: typing.Type[EventSetDescriptor]
    ExceptionListener: typing.Type[ExceptionListener]
    Expression: typing.Type[Expression]
    FeatureDescriptor: typing.Type[FeatureDescriptor]
    IndexedPropertyChangeEvent: typing.Type[IndexedPropertyChangeEvent]
    IndexedPropertyDescriptor: typing.Type[IndexedPropertyDescriptor]
    IntrospectionException: typing.Type[IntrospectionException]
    Introspector: typing.Type[Introspector]
    JavaBean: typing.Type[JavaBean]
    MethodDescriptor: typing.Type[MethodDescriptor]
    ParameterDescriptor: typing.Type[ParameterDescriptor]
    PersistenceDelegate: typing.Type[PersistenceDelegate]
    PropertyChangeEvent: typing.Type[PropertyChangeEvent]
    PropertyChangeListener: typing.Type[PropertyChangeListener]
    PropertyChangeListenerProxy: typing.Type[PropertyChangeListenerProxy]
    PropertyChangeSupport: typing.Type[PropertyChangeSupport]
    PropertyDescriptor: typing.Type[PropertyDescriptor]
    PropertyEditor: typing.Type[PropertyEditor]
    PropertyEditorManager: typing.Type[PropertyEditorManager]
    PropertyEditorSupport: typing.Type[PropertyEditorSupport]
    PropertyVetoException: typing.Type[PropertyVetoException]
    SimpleBeanInfo: typing.Type[SimpleBeanInfo]
    Statement: typing.Type[Statement]
    Transient: typing.Type[Transient]
    VetoableChangeListener: typing.Type[VetoableChangeListener]
    VetoableChangeListenerProxy: typing.Type[VetoableChangeListenerProxy]
    VetoableChangeSupport: typing.Type[VetoableChangeSupport]
    Visibility: typing.Type[Visibility]
    XMLDecoder: typing.Type[XMLDecoder]
    XMLEncoder: typing.Type[XMLEncoder]
    beancontext: java.beans.beancontext.__module_protocol__



import java.lang
import java.text
import java.time
import java.time.chrono
import java.time.temporal
import java.util
import typing



class DateTimeFormatter:
    ISO_LOCAL_DATE: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_OFFSET_DATE: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_DATE: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_LOCAL_TIME: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_OFFSET_TIME: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_TIME: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_LOCAL_DATE_TIME: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_OFFSET_DATE_TIME: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_ZONED_DATE_TIME: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_DATE_TIME: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_ORDINAL_DATE: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_WEEK_DATE: typing.ClassVar['DateTimeFormatter'] = ...
    ISO_INSTANT: typing.ClassVar['DateTimeFormatter'] = ...
    BASIC_ISO_DATE: typing.ClassVar['DateTimeFormatter'] = ...
    RFC_1123_DATE_TIME: typing.ClassVar['DateTimeFormatter'] = ...
    def format(self, temporalAccessor: java.time.temporal.TemporalAccessor) -> str: ...
    def formatTo(self, temporalAccessor: java.time.temporal.TemporalAccessor, appendable: java.lang.Appendable) -> None: ...
    def getChronology(self) -> java.time.chrono.Chronology: ...
    def getDecimalStyle(self) -> 'DecimalStyle': ...
    def getLocale(self) -> java.util.Locale: ...
    def getResolverFields(self) -> java.util.Set[java.time.temporal.TemporalField]: ...
    def getResolverStyle(self) -> 'ResolverStyle': ...
    def getZone(self) -> java.time.ZoneId: ...
    def localizedBy(self, locale: java.util.Locale) -> 'DateTimeFormatter': ...
    @staticmethod
    def ofLocalizedDate(formatStyle: 'FormatStyle') -> 'DateTimeFormatter': ...
    @typing.overload
    @staticmethod
    def ofLocalizedDateTime(formatStyle: 'FormatStyle') -> 'DateTimeFormatter': ...
    @typing.overload
    @staticmethod
    def ofLocalizedDateTime(formatStyle: 'FormatStyle', formatStyle2: 'FormatStyle') -> 'DateTimeFormatter': ...
    @staticmethod
    def ofLocalizedTime(formatStyle: 'FormatStyle') -> 'DateTimeFormatter': ...
    @typing.overload
    @staticmethod
    def ofPattern(string: str) -> 'DateTimeFormatter': ...
    @typing.overload
    @staticmethod
    def ofPattern(string: str, locale: java.util.Locale) -> 'DateTimeFormatter': ...
    _parse_0__T = typing.TypeVar('_parse_0__T')  # <T>
    @typing.overload
    def parse(self, charSequence: typing.Union[java.lang.CharSequence, str], temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_parse_0__T], typing.Callable[[java.time.temporal.TemporalAccessor], _parse_0__T]]) -> _parse_0__T: ...
    @typing.overload
    def parse(self, charSequence: typing.Union[java.lang.CharSequence, str]) -> java.time.temporal.TemporalAccessor: ...
    @typing.overload
    def parse(self, charSequence: typing.Union[java.lang.CharSequence, str], parsePosition: java.text.ParsePosition) -> java.time.temporal.TemporalAccessor: ...
    def parseBest(self, charSequence: typing.Union[java.lang.CharSequence, str], temporalQueryArray: typing.List[java.time.temporal.TemporalQuery[typing.Any]]) -> java.time.temporal.TemporalAccessor: ...
    def parseUnresolved(self, charSequence: typing.Union[java.lang.CharSequence, str], parsePosition: java.text.ParsePosition) -> java.time.temporal.TemporalAccessor: ...
    @staticmethod
    def parsedExcessDays() -> java.time.temporal.TemporalQuery[java.time.Period]: ...
    @staticmethod
    def parsedLeapSecond() -> java.time.temporal.TemporalQuery[bool]: ...
    @typing.overload
    def toFormat(self) -> java.text.Format: ...
    @typing.overload
    def toFormat(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[typing.Any], typing.Callable[[java.time.temporal.TemporalAccessor], typing.Any]]) -> java.text.Format: ...
    def toString(self) -> str: ...
    def withChronology(self, chronology: java.time.chrono.Chronology) -> 'DateTimeFormatter': ...
    def withDecimalStyle(self, decimalStyle: 'DecimalStyle') -> 'DateTimeFormatter': ...
    def withLocale(self, locale: java.util.Locale) -> 'DateTimeFormatter': ...
    @typing.overload
    def withResolverFields(self, temporalFieldArray: typing.List[java.time.temporal.TemporalField]) -> 'DateTimeFormatter': ...
    @typing.overload
    def withResolverFields(self, set: java.util.Set[java.time.temporal.TemporalField]) -> 'DateTimeFormatter': ...
    def withResolverStyle(self, resolverStyle: 'ResolverStyle') -> 'DateTimeFormatter': ...
    def withZone(self, zoneId: java.time.ZoneId) -> 'DateTimeFormatter': ...

class DateTimeFormatterBuilder:
    def __init__(self): ...
    def append(self, dateTimeFormatter: DateTimeFormatter) -> 'DateTimeFormatterBuilder': ...
    def appendChronologyId(self) -> 'DateTimeFormatterBuilder': ...
    def appendChronologyText(self, textStyle: 'TextStyle') -> 'DateTimeFormatterBuilder': ...
    def appendFraction(self, temporalField: java.time.temporal.TemporalField, int: int, int2: int, boolean: bool) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendGenericZoneText(self, textStyle: 'TextStyle') -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendGenericZoneText(self, textStyle: 'TextStyle', set: java.util.Set[java.time.ZoneId]) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendInstant(self) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendInstant(self, int: int) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendLiteral(self, char: str) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendLiteral(self, string: str) -> 'DateTimeFormatterBuilder': ...
    def appendLocalized(self, formatStyle: 'FormatStyle', formatStyle2: 'FormatStyle') -> 'DateTimeFormatterBuilder': ...
    def appendLocalizedOffset(self, textStyle: 'TextStyle') -> 'DateTimeFormatterBuilder': ...
    def appendOffset(self, string: str, string2: str) -> 'DateTimeFormatterBuilder': ...
    def appendOffsetId(self) -> 'DateTimeFormatterBuilder': ...
    def appendOptional(self, dateTimeFormatter: DateTimeFormatter) -> 'DateTimeFormatterBuilder': ...
    def appendPattern(self, string: str) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendText(self, temporalField: java.time.temporal.TemporalField) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendText(self, temporalField: java.time.temporal.TemporalField, textStyle: 'TextStyle') -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendText(self, temporalField: java.time.temporal.TemporalField, map: typing.Union[java.util.Map[int, str], typing.Mapping[int, str]]) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendValue(self, temporalField: java.time.temporal.TemporalField) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendValue(self, temporalField: java.time.temporal.TemporalField, int: int) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendValue(self, temporalField: java.time.temporal.TemporalField, int: int, int2: int, signStyle: 'SignStyle') -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendValueReduced(self, temporalField: java.time.temporal.TemporalField, int: int, int2: int, int3: int) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendValueReduced(self, temporalField: java.time.temporal.TemporalField, int: int, int2: int, chronoLocalDate: java.time.chrono.ChronoLocalDate) -> 'DateTimeFormatterBuilder': ...
    def appendZoneId(self) -> 'DateTimeFormatterBuilder': ...
    def appendZoneOrOffsetId(self) -> 'DateTimeFormatterBuilder': ...
    def appendZoneRegionId(self) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendZoneText(self, textStyle: 'TextStyle') -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def appendZoneText(self, textStyle: 'TextStyle', set: java.util.Set[java.time.ZoneId]) -> 'DateTimeFormatterBuilder': ...
    @staticmethod
    def getLocalizedDateTimePattern(formatStyle: 'FormatStyle', formatStyle2: 'FormatStyle', chronology: java.time.chrono.Chronology, locale: java.util.Locale) -> str: ...
    def optionalEnd(self) -> 'DateTimeFormatterBuilder': ...
    def optionalStart(self) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def padNext(self, int: int) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def padNext(self, int: int, char: str) -> 'DateTimeFormatterBuilder': ...
    def parseCaseInsensitive(self) -> 'DateTimeFormatterBuilder': ...
    def parseCaseSensitive(self) -> 'DateTimeFormatterBuilder': ...
    def parseDefaulting(self, temporalField: java.time.temporal.TemporalField, long: int) -> 'DateTimeFormatterBuilder': ...
    def parseLenient(self) -> 'DateTimeFormatterBuilder': ...
    def parseStrict(self) -> 'DateTimeFormatterBuilder': ...
    @typing.overload
    def toFormatter(self) -> DateTimeFormatter: ...
    @typing.overload
    def toFormatter(self, locale: java.util.Locale) -> DateTimeFormatter: ...

class DateTimeParseException(java.time.DateTimeException):
    @typing.overload
    def __init__(self, string: str, charSequence: typing.Union[java.lang.CharSequence, str], int: int): ...
    @typing.overload
    def __init__(self, string: str, charSequence: typing.Union[java.lang.CharSequence, str], int: int, throwable: java.lang.Throwable): ...
    def getErrorIndex(self) -> int: ...
    def getParsedString(self) -> str: ...

class DecimalStyle:
    STANDARD: typing.ClassVar['DecimalStyle'] = ...
    def equals(self, object: typing.Any) -> bool: ...
    @staticmethod
    def getAvailableLocales() -> java.util.Set[java.util.Locale]: ...
    def getDecimalSeparator(self) -> str: ...
    def getNegativeSign(self) -> str: ...
    def getPositiveSign(self) -> str: ...
    def getZeroDigit(self) -> str: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def of(locale: java.util.Locale) -> 'DecimalStyle': ...
    @staticmethod
    def ofDefaultLocale() -> 'DecimalStyle': ...
    def toString(self) -> str: ...
    def withDecimalSeparator(self, char: str) -> 'DecimalStyle': ...
    def withNegativeSign(self, char: str) -> 'DecimalStyle': ...
    def withPositiveSign(self, char: str) -> 'DecimalStyle': ...
    def withZeroDigit(self, char: str) -> 'DecimalStyle': ...

class FormatStyle(java.lang.Enum['FormatStyle']):
    FULL: typing.ClassVar['FormatStyle'] = ...
    LONG: typing.ClassVar['FormatStyle'] = ...
    MEDIUM: typing.ClassVar['FormatStyle'] = ...
    SHORT: typing.ClassVar['FormatStyle'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'FormatStyle': ...
    @staticmethod
    def values() -> typing.List['FormatStyle']: ...

class ResolverStyle(java.lang.Enum['ResolverStyle']):
    STRICT: typing.ClassVar['ResolverStyle'] = ...
    SMART: typing.ClassVar['ResolverStyle'] = ...
    LENIENT: typing.ClassVar['ResolverStyle'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'ResolverStyle': ...
    @staticmethod
    def values() -> typing.List['ResolverStyle']: ...

class SignStyle(java.lang.Enum['SignStyle']):
    NORMAL: typing.ClassVar['SignStyle'] = ...
    ALWAYS: typing.ClassVar['SignStyle'] = ...
    NEVER: typing.ClassVar['SignStyle'] = ...
    NOT_NEGATIVE: typing.ClassVar['SignStyle'] = ...
    EXCEEDS_PAD: typing.ClassVar['SignStyle'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'SignStyle': ...
    @staticmethod
    def values() -> typing.List['SignStyle']: ...

class TextStyle(java.lang.Enum['TextStyle']):
    FULL: typing.ClassVar['TextStyle'] = ...
    FULL_STANDALONE: typing.ClassVar['TextStyle'] = ...
    SHORT: typing.ClassVar['TextStyle'] = ...
    SHORT_STANDALONE: typing.ClassVar['TextStyle'] = ...
    NARROW: typing.ClassVar['TextStyle'] = ...
    NARROW_STANDALONE: typing.ClassVar['TextStyle'] = ...
    def asNormal(self) -> 'TextStyle': ...
    def asStandalone(self) -> 'TextStyle': ...
    def isStandalone(self) -> bool: ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'TextStyle': ...
    @staticmethod
    def values() -> typing.List['TextStyle']: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.time.format")``.

    DateTimeFormatter: typing.Type[DateTimeFormatter]
    DateTimeFormatterBuilder: typing.Type[DateTimeFormatterBuilder]
    DateTimeParseException: typing.Type[DateTimeParseException]
    DecimalStyle: typing.Type[DecimalStyle]
    FormatStyle: typing.Type[FormatStyle]
    ResolverStyle: typing.Type[ResolverStyle]
    SignStyle: typing.Type[SignStyle]
    TextStyle: typing.Type[TextStyle]



import java.awt
import java.beans
import java.io
import java.net
import java.util
import java.util.function
import typing



class BeanContextChild:
    def addPropertyChangeListener(self, string: str, propertyChangeListener: java.beans.PropertyChangeListener) -> None: ...
    def addVetoableChangeListener(self, string: str, vetoableChangeListener: java.beans.VetoableChangeListener) -> None: ...
    def getBeanContext(self) -> 'BeanContext': ...
    def removePropertyChangeListener(self, string: str, propertyChangeListener: java.beans.PropertyChangeListener) -> None: ...
    def removeVetoableChangeListener(self, string: str, vetoableChangeListener: java.beans.VetoableChangeListener) -> None: ...
    def setBeanContext(self, beanContext: 'BeanContext') -> None: ...

class BeanContextChildComponentProxy:
    def getComponent(self) -> java.awt.Component: ...

class BeanContextContainerProxy:
    def getContainer(self) -> java.awt.Container: ...

class BeanContextEvent(java.util.EventObject):
    def getBeanContext(self) -> 'BeanContext': ...
    def getPropagatedFrom(self) -> 'BeanContext': ...
    def isPropagated(self) -> bool: ...
    def setPropagatedFrom(self, beanContext: 'BeanContext') -> None: ...

class BeanContextMembershipListener(java.util.EventListener):
    def childrenAdded(self, beanContextMembershipEvent: 'BeanContextMembershipEvent') -> None: ...
    def childrenRemoved(self, beanContextMembershipEvent: 'BeanContextMembershipEvent') -> None: ...

class BeanContextProxy:
    def getBeanContextProxy(self) -> BeanContextChild: ...

class BeanContextServiceProvider:
    def getCurrentServiceSelectors(self, beanContextServices: 'BeanContextServices', class_: typing.Type[typing.Any]) -> java.util.Iterator[typing.Any]: ...
    def getService(self, beanContextServices: 'BeanContextServices', object: typing.Any, class_: typing.Type[typing.Any], object2: typing.Any) -> typing.Any: ...
    def releaseService(self, beanContextServices: 'BeanContextServices', object: typing.Any, object2: typing.Any) -> None: ...

class BeanContextServiceProviderBeanInfo(java.beans.BeanInfo):
    def getServicesBeanInfo(self) -> typing.List[java.beans.BeanInfo]: ...

class BeanContextServiceRevokedListener(java.util.EventListener):
    def serviceRevoked(self, beanContextServiceRevokedEvent: 'BeanContextServiceRevokedEvent') -> None: ...

class BeanContext(BeanContextChild, java.util.Collection, java.beans.DesignMode, java.beans.Visibility):
    globalHierarchyLock: typing.ClassVar[typing.Any] = ...
    def addBeanContextMembershipListener(self, beanContextMembershipListener: BeanContextMembershipListener) -> None: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getResource(self, string: str, beanContextChild: BeanContextChild) -> java.net.URL: ...
    def getResourceAsStream(self, string: str, beanContextChild: BeanContextChild) -> java.io.InputStream: ...
    def hashCode(self) -> int: ...
    def instantiateChild(self, string: str) -> typing.Any: ...
    def removeBeanContextMembershipListener(self, beanContextMembershipListener: BeanContextMembershipListener) -> None: ...

class BeanContextMembershipEvent(BeanContextEvent):
    @typing.overload
    def __init__(self, beanContext: BeanContext, objectArray: typing.List[typing.Any]): ...
    @typing.overload
    def __init__(self, beanContext: BeanContext, collection: typing.Union[java.util.Collection, typing.Sequence, typing.Set]): ...
    def contains(self, object: typing.Any) -> bool: ...
    def iterator(self) -> java.util.Iterator: ...
    def size(self) -> int: ...
    def toArray(self) -> typing.List[typing.Any]: ...

class BeanContextServiceAvailableEvent(BeanContextEvent):
    def __init__(self, beanContextServices: 'BeanContextServices', class_: typing.Type[typing.Any]): ...
    def getCurrentServiceSelectors(self) -> java.util.Iterator[typing.Any]: ...
    def getServiceClass(self) -> typing.Type[typing.Any]: ...
    def getSourceAsBeanContextServices(self) -> 'BeanContextServices': ...

class BeanContextServiceRevokedEvent(BeanContextEvent):
    def __init__(self, beanContextServices: 'BeanContextServices', class_: typing.Type[typing.Any], boolean: bool): ...
    def getServiceClass(self) -> typing.Type[typing.Any]: ...
    def getSourceAsBeanContextServices(self) -> 'BeanContextServices': ...
    def isCurrentServiceInvalidNow(self) -> bool: ...
    def isServiceClass(self, class_: typing.Type[typing.Any]) -> bool: ...

class BeanContextServicesListener(BeanContextServiceRevokedListener):
    def serviceAvailable(self, beanContextServiceAvailableEvent: BeanContextServiceAvailableEvent) -> None: ...

class BeanContextChildSupport(BeanContextChild, BeanContextServicesListener, java.io.Serializable):
    beanContextChildPeer: BeanContextChild = ...
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, beanContextChild: BeanContextChild): ...
    def addPropertyChangeListener(self, string: str, propertyChangeListener: java.beans.PropertyChangeListener) -> None: ...
    def addVetoableChangeListener(self, string: str, vetoableChangeListener: java.beans.VetoableChangeListener) -> None: ...
    def firePropertyChange(self, string: str, object: typing.Any, object2: typing.Any) -> None: ...
    def fireVetoableChange(self, string: str, object: typing.Any, object2: typing.Any) -> None: ...
    def getBeanContext(self) -> BeanContext: ...
    def getBeanContextChildPeer(self) -> BeanContextChild: ...
    def isDelegated(self) -> bool: ...
    def removePropertyChangeListener(self, string: str, propertyChangeListener: java.beans.PropertyChangeListener) -> None: ...
    def removeVetoableChangeListener(self, string: str, vetoableChangeListener: java.beans.VetoableChangeListener) -> None: ...
    def serviceAvailable(self, beanContextServiceAvailableEvent: BeanContextServiceAvailableEvent) -> None: ...
    def serviceRevoked(self, beanContextServiceRevokedEvent: BeanContextServiceRevokedEvent) -> None: ...
    def setBeanContext(self, beanContext: BeanContext) -> None: ...
    def validatePendingSetBeanContext(self, beanContext: BeanContext) -> bool: ...

class BeanContextServices(BeanContext, BeanContextServicesListener):
    def addBeanContextServicesListener(self, beanContextServicesListener: BeanContextServicesListener) -> None: ...
    def addService(self, class_: typing.Type[typing.Any], beanContextServiceProvider: BeanContextServiceProvider) -> bool: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getCurrentServiceClasses(self) -> java.util.Iterator[typing.Any]: ...
    def getCurrentServiceSelectors(self, class_: typing.Type[typing.Any]) -> java.util.Iterator[typing.Any]: ...
    def getService(self, beanContextChild: BeanContextChild, object: typing.Any, class_: typing.Type[typing.Any], object2: typing.Any, beanContextServiceRevokedListener: BeanContextServiceRevokedListener) -> typing.Any: ...
    def hasService(self, class_: typing.Type[typing.Any]) -> bool: ...
    def hashCode(self) -> int: ...
    def releaseService(self, beanContextChild: BeanContextChild, object: typing.Any, object2: typing.Any) -> None: ...
    def removeBeanContextServicesListener(self, beanContextServicesListener: BeanContextServicesListener) -> None: ...
    def revokeService(self, class_: typing.Type[typing.Any], beanContextServiceProvider: BeanContextServiceProvider, boolean: bool) -> None: ...

class BeanContextSupport(BeanContextChildSupport, BeanContext, java.io.Serializable, java.beans.PropertyChangeListener, java.beans.VetoableChangeListener):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, beanContext: BeanContext): ...
    @typing.overload
    def __init__(self, beanContext: BeanContext, locale: java.util.Locale): ...
    @typing.overload
    def __init__(self, beanContext: BeanContext, locale: java.util.Locale, boolean: bool): ...
    @typing.overload
    def __init__(self, beanContext: BeanContext, locale: java.util.Locale, boolean: bool, boolean2: bool): ...
    def add(self, object: typing.Any) -> bool: ...
    def addAll(self, collection: typing.Union[java.util.Collection, typing.Sequence, typing.Set]) -> bool: ...
    def addBeanContextMembershipListener(self, beanContextMembershipListener: BeanContextMembershipListener) -> None: ...
    def avoidingGui(self) -> bool: ...
    def clear(self) -> None: ...
    def contains(self, object: typing.Any) -> bool: ...
    def containsAll(self, collection: typing.Union[java.util.Collection, typing.Sequence, typing.Set]) -> bool: ...
    def containsKey(self, object: typing.Any) -> bool: ...
    def dontUseGui(self) -> None: ...
    def getBeanContextPeer(self) -> BeanContext: ...
    def getLocale(self) -> java.util.Locale: ...
    def getResource(self, string: str, beanContextChild: BeanContextChild) -> java.net.URL: ...
    def getResourceAsStream(self, string: str, beanContextChild: BeanContextChild) -> java.io.InputStream: ...
    def instantiateChild(self, string: str) -> typing.Any: ...
    def isDesignTime(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def isSerializing(self) -> bool: ...
    def iterator(self) -> java.util.Iterator[typing.Any]: ...
    def needsGui(self) -> bool: ...
    def okToUseGui(self) -> None: ...
    def propertyChange(self, propertyChangeEvent: java.beans.PropertyChangeEvent) -> None: ...
    def readChildren(self, objectInputStream: java.io.ObjectInputStream) -> None: ...
    def remove(self, object: typing.Any) -> bool: ...
    def removeAll(self, collection: typing.Union[java.util.Collection, typing.Sequence, typing.Set]) -> bool: ...
    def removeBeanContextMembershipListener(self, beanContextMembershipListener: BeanContextMembershipListener) -> None: ...
    def retainAll(self, collection: typing.Union[java.util.Collection, typing.Sequence, typing.Set]) -> bool: ...
    def setDesignTime(self, boolean: bool) -> None: ...
    def setLocale(self, locale: java.util.Locale) -> None: ...
    def size(self) -> int: ...
    _toArray_0__T = typing.TypeVar('_toArray_0__T')  # <T>
    @typing.overload
    def toArray(self, intFunction: typing.Union[java.util.function.IntFunction[typing.List[_toArray_0__T]], typing.Callable[[int], typing.List[_toArray_0__T]]]) -> typing.List[_toArray_0__T]: ...
    @typing.overload
    def toArray(self) -> typing.List[typing.Any]: ...
    @typing.overload
    def toArray(self, objectArray: typing.List[typing.Any]) -> typing.List[typing.Any]: ...
    def vetoableChange(self, propertyChangeEvent: java.beans.PropertyChangeEvent) -> None: ...
    def writeChildren(self, objectOutputStream: java.io.ObjectOutputStream) -> None: ...

class BeanContextServicesSupport(BeanContextSupport, BeanContextServices):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, beanContextServices: BeanContextServices): ...
    @typing.overload
    def __init__(self, beanContextServices: BeanContextServices, locale: java.util.Locale): ...
    @typing.overload
    def __init__(self, beanContextServices: BeanContextServices, locale: java.util.Locale, boolean: bool): ...
    @typing.overload
    def __init__(self, beanContextServices: BeanContextServices, locale: java.util.Locale, boolean: bool, boolean2: bool): ...
    def addBeanContextServicesListener(self, beanContextServicesListener: BeanContextServicesListener) -> None: ...
    def addService(self, class_: typing.Type[typing.Any], beanContextServiceProvider: BeanContextServiceProvider) -> bool: ...
    def getBeanContextServicesPeer(self) -> BeanContextServices: ...
    def getCurrentServiceClasses(self) -> java.util.Iterator[typing.Any]: ...
    def getCurrentServiceSelectors(self, class_: typing.Type[typing.Any]) -> java.util.Iterator[typing.Any]: ...
    def getService(self, beanContextChild: BeanContextChild, object: typing.Any, class_: typing.Type[typing.Any], object2: typing.Any, beanContextServiceRevokedListener: BeanContextServiceRevokedListener) -> typing.Any: ...
    def hasService(self, class_: typing.Type[typing.Any]) -> bool: ...
    def initialize(self) -> None: ...
    def releaseService(self, beanContextChild: BeanContextChild, object: typing.Any, object2: typing.Any) -> None: ...
    def removeBeanContextServicesListener(self, beanContextServicesListener: BeanContextServicesListener) -> None: ...
    def revokeService(self, class_: typing.Type[typing.Any], beanContextServiceProvider: BeanContextServiceProvider, boolean: bool) -> None: ...
    def serviceAvailable(self, beanContextServiceAvailableEvent: BeanContextServiceAvailableEvent) -> None: ...
    def serviceRevoked(self, beanContextServiceRevokedEvent: BeanContextServiceRevokedEvent) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.beans.beancontext")``.

    BeanContext: typing.Type[BeanContext]
    BeanContextChild: typing.Type[BeanContextChild]
    BeanContextChildComponentProxy: typing.Type[BeanContextChildComponentProxy]
    BeanContextChildSupport: typing.Type[BeanContextChildSupport]
    BeanContextContainerProxy: typing.Type[BeanContextContainerProxy]
    BeanContextEvent: typing.Type[BeanContextEvent]
    BeanContextMembershipEvent: typing.Type[BeanContextMembershipEvent]
    BeanContextMembershipListener: typing.Type[BeanContextMembershipListener]
    BeanContextProxy: typing.Type[BeanContextProxy]
    BeanContextServiceAvailableEvent: typing.Type[BeanContextServiceAvailableEvent]
    BeanContextServiceProvider: typing.Type[BeanContextServiceProvider]
    BeanContextServiceProviderBeanInfo: typing.Type[BeanContextServiceProviderBeanInfo]
    BeanContextServiceRevokedEvent: typing.Type[BeanContextServiceRevokedEvent]
    BeanContextServiceRevokedListener: typing.Type[BeanContextServiceRevokedListener]
    BeanContextServices: typing.Type[BeanContextServices]
    BeanContextServicesListener: typing.Type[BeanContextServicesListener]
    BeanContextServicesSupport: typing.Type[BeanContextServicesSupport]
    BeanContextSupport: typing.Type[BeanContextSupport]
